'use strict';
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileSystemFunctions = void 0;
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
const fse = __importStar(require("fs-extra"));
const fsp = fs.promises;
const jsonFuture = __importStar(require("json-future"));
class FileSystemFunctions {
    constructor() {
        this.getFilesAsync = async (dir) => {
            let files = [];
            const getFiles = async (folder) => {
                files = await fsp.readdir(folder);
                const result = files.map((file) => {
                    const p = path.join(folder, file);
                    return fsp.stat(p).then((stat) => (stat.isDirectory() ? getFiles(p) : [p]));
                });
                return Array.prototype.concat(...(await Promise.all(result))); // Flatten
            };
            return getFiles(dir);
        };
        this.checkFolder = async (file) => fsp
            .stat(file)
            .then((result) => result.isDirectory())
            .catch(() => false);
        this.readJsonFeatureFile = async (file, encoding = 'utf8') => fse.readJson(file, { encoding }).catch((error) => {
            console.log(`The file ${file} is not a valid json, it has the error message ${error.message}`);
            return null;
        });
        this.readJsonExtendedReportFile = async (file, encoding = 'utf8') => fse.readJson(file, { encoding }).catch((error) => {
            console.log(`The file ${file} is not a valid json, it has the error message ${error.message}`);
            return null;
        });
        this.parseJsonObject = async (jsonObject) => jsonFuture.parseAsync(await jsonFuture.stringifyAsync(jsonObject));
        this.readFeatureFile = async (file, enconding) => {
            const parsedReport = await this.readJsonFeatureFile(file, enconding);
            if (parsedReport == null ||
                typeof parsedReport.length === 'undefined' ||
                parsedReport.length === 0 ||
                typeof parsedReport[0].id === 'undefined' ||
                typeof parsedReport[0].keyword === 'undefined') {
                const arr = [];
                return arr;
            }
            return parsedReport;
        };
        this.writeJson = async (destinationFile, jsonObject) => fse.writeFile(destinationFile, jsonObject);
        this.convertJsonObjectToString = async (object) => jsonFuture.stringifyAsync(object);
        this.saveJsonFile = async (file, json) => {
            const jsonString = await jsonFuture.stringify(json);
            await this.writeJson(file, jsonString);
            return true;
        };
    }
}
exports.FileSystemFunctions = FileSystemFunctions;
//# sourceMappingURL=file-system-functions.js.map